Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1497)

Unified Diff: content/public/test/layouttest_support.h

Issue 2415083002: Move Device Sensors client files from Blink to //device/sensors client lib (Closed)
Patch Set: Fix gn check Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/test/layouttest_support.h
diff --git a/content/public/test/layouttest_support.h b/content/public/test/layouttest_support.h
index b7a77d129f7cf472b322acc0b9ebfca427314c10..c15d84c08b32374c6aecdf8e6c5e9856c0048b40 100644
--- a/content/public/test/layouttest_support.h
+++ b/content/public/test/layouttest_support.h
@@ -18,8 +18,6 @@
class GURL;
namespace blink {
-class WebDeviceMotionData;
-class WebDeviceOrientationData;
class WebGamepad;
class WebGamepads;
class WebInputEvent;
@@ -33,6 +31,8 @@ class WebURLResponse;
namespace device {
class BluetoothAdapter;
+class MotionData;
+class OrientationData;
}
namespace gfx {
@@ -110,13 +110,13 @@ void SetMockGamepadProvider(std::unique_ptr<RendererGamepadProvider> provider);
// a listener through BlinkPlatformImpl::setDeviceLightListener().
void SetMockDeviceLightData(const double data);
// Sets WebDeviceMotionData that should be used when registering
// a listener through BlinkPlatformImpl::setDeviceMotionListener().
-void SetMockDeviceMotionData(const blink::WebDeviceMotionData& data);
+void SetMockDeviceMotionData(const device::MotionData& data);
-// Sets WebDeviceOrientationData that should be used when registering
+// Sets OrientationData that should be used when registering
// a listener through BlinkPlatformImpl::setDeviceOrientationListener().
-void SetMockDeviceOrientationData(const blink::WebDeviceOrientationData& data);
+void SetMockDeviceOrientationData(const device::OrientationData& data);
// Returns the length of the local session history of a render view.
int GetLocalSessionHistoryLength(RenderView* render_view);
@@ -110,13 +110,13 @@ void SetMockGamepadProvider(std::unique_ptr<RendererGamepadProvider> provider);
// a listener through BlinkPlatformImpl::setDeviceLightListener().
void SetMockDeviceLightData(const double data);
-// Sets WebDeviceMotionData that should be used when registering
+// Sets MotionData that should be used when registering
// a listener through BlinkPlatformImpl::setDeviceMotionListener().

Powered by Google App Engine
This is Rietveld 408576698